==> ?mortyurl=https%3A%2F%2Fdl.google.com%2Fgoogleadmobadssdk%2Fmediation%2Fios%2Fmytarget%2FMyTargetAdapter-5.7.4.0.zip: MyTargetAdapter-5.7.4.0/CHANGELOG.md <==
## myTarget iOS Mediation Adapter Changelog

#### Version 5.7.4.0
- Verified compatibility with myTarget SDK version 5.7.4.
- Now requires Google Mobile Ads SDK version 7.64.0 or higher.

Build and tested With:
- Google Mobile Ads SDK version 7.64.0.
- MyTarget SDK version 5.7.4

#### Version 5.7.3.0
- Verified compatibility with myTarget SDK version 5.7.3.
- Now requires Google Mobile Ads SDK version 7.63.0 or higher.

Build and tested With:
- Google Mobile Ads SDK version 7.63.0.
- MyTarget SDK version 5.7.3

#### Version 5.7.2.0
- Verified compatibility with myTarget SDK version 5.7.2.

Build and tested With:
- Google Mobile Ads SDK version 7.62.0.
- MyTarget SDK version 5.7.2

#### Version 5.7.1.0
- Verified compatibility with myTarget SDK version 5.7.1.

Build and tested With:
- Google Mobile Ads SDK version 7.61.0.
- MyTarget SDK version 5.7.1

#### Version 5.7.0.0
- Verified compatibility with myTarget SDK version 5.7.0.

Build and tested With:
- Google Mobile Ads SDK version 7.61.0.
- MyTarget SDK version 5.7.0
.
#### Version 5.6.3.0
- Verified compatibility with myTarget SDK version 5.6.3.
- Now requires Google Mobile Ads SDK version 7.61.0 or higher.

Build and tested With:
- Google Mobile Ads SDK version 7.61.0.
- MyTarget SDK version 5.6.3.

#### Version 5.6.2.0
- Verified compatibility with myTarget SDK version 5.6.2.

Build and tested With:
- Google Mobile Ads SDK version 7.60.0.
- MyTarget SDK version 5.6.2.

#### Version 5.6.1.0
- Verified compatibility with myTarget SDK version 5.6.1.

Build and tested With:
- Google Mobile Ads SDK version 7.60.0.
- MyTarget SDK version 5.6.1.

#### Version 5.6.0.0
- Verified compatibility with myTarget SDK version 5.6.0.
- Now requires Google Mobile Ads SDK version 7.60.0 or higher.

Build and tested With:
- Google Mobile Ads SDK version 7.60.0.
- MyTarget SDK version 5.6.0.

#### Version 5.5.2.0
- Verified compatibility with myTarget SDK version 5.5.2.
- Now requires Google Mobile Ads SDK version 7.59.0 or higher.

Build and tested With:
- Google Mobile Ads SDK version 7.59.0.
- MyTarget SDK version 5.5.2.

#### Version 5.5.1.0
- Verified compatibility with myTarget SDK version 5.5.1.
- Now requires Google Mobile Ads SDK version 7.58.0 or higher.

Build and tested With:
- Google Mobile Ads SDK version 7.58.0.
- MyTarget SDK version 5.5.1.

#### Version 5.4.9.0
- Verified compatibility with myTarget SDK version 5.4.9.
- Removed support for the i386 architecture.

Build and tested With:
- Google Mobile Ads SDK version 7.57.0.
- MyTarget SDK version 5.4.9.

#### Version 5.4.7.0
- Verified compatibility with myTarget SDK version 5.4.7.
- Now requires minimum iOS version 9.0.

Build and tested With:
- Google Mobile Ads SDK version 7.55.1.
- MyTarget SDK version 5.4.7.

#### Version 5.4.5.0
- Verified compatibility with myTarget SDK version 5.4.5.

Build and tested With:
- Google Mobile Ads SDK version 7.53.1.
- MyTarget SDK version 5.4.5.

#### Version 5.4.2.0
- Verified compatibility with myTarget SDK version 5.4.2.
- Adapter now returns a non-zero `mediaContent` aspect ratio.

Build and tested With:
- Google Mobile Ads SDK version 7.53.1.
- MyTarget SDK version 5.4.2.

#### Version 5.3.3.0
- Verified compatibility with myTarget SDK version 5.3.3.
- Removed support for Native Content and App Install ad requests. Apps must use the Unified Native Ads API to request native ads.
- Now requires Google Mobile Ads SDK version 7.46.0 or higher.

#### Version 5.0.4.0
- Verified compatibility with myTarget SDK version 5.0.4.
- Updated the adapter to use the new rewarded API.
- Now requires Google Mobile Ads SDK version 7.41.0 or higher.

#### Version 5.0.1.0
- Verified compatibility with myTarget SDK version 5.0.1.

#### Version 4.8.9.0
- Verified compatibility with myTarget SDK version 4.8.9.

#### Version 4.8.5.0
- Verified compatibility with myTarget SDK version 4.8.5.

#### Version 4.8.0.0
- Verified compatibility with myTarget SDK version 4.8.0.

#### Version 4.7.11.0
- Verified compatibility with myTarget SDK version 4.7.11.

#### Version 4.7.10.0
- Verified compatibility with myTarget SDK version 4.7.10.
- Added `adapterDidCompletePlayingRewardBasedVideoAd:` callback to the adapter.

#### Version 4.7.9.1
- Added support for Unified native ad.

#### Version 4.7.9.0
- Verified compatibility with myTarget SDK version 4.7.9.
- Added support for unified native ad.

#### Version 4.7.8.0
- Verified compatibility with myTarget SDK version 4.7.8.

#### Version 4.7.7.0
- Verified compatibility with myTarget SDK version 4.7.7.

#### Version 4.7.6.0
- Verified compatibility with myTarget SDK version 4.7.6.

#### Version 4.7.5.0
- Verified compatibility with myTarget SDK version 4.7.5.

#### Version 4.7.4.0
- Verified compatibility with myTarget SDK version 4.7.4.

#### Version 4.7.3.0
- Verified compatibility with myTarget SDK version 4.7.3.
- Added support for native video ads.

#### Version 4.6.25.0
- Verified compatibility with myTarget SDK version 4.6.25.

#### Version 4.6.24.0
- First release!
- Added support for banner, interstitial, rewarded, and native ads.

==> ?mortyurl=https%3A%2F%2Fdl.google.com%2Fgoogleadmobadssdk%2Fmediation%2Fios%2Fmytarget%2FMyTargetAdapter-5.9.11.0.zip: MyTargetAdapter-5.9.11.0/CHANGELOG.md <==
## myTarget iOS Mediation Adapter Changelog

#### Version 5.9.11.0
- Verified compatibility with myTarget SDK version 5.9.10.

Build and tested With:
- Google Mobile Ads SDK version 7.69.0.
- MyTarget SDK version 5.9.11

#### Version 5.9.10.0
- Verified compatibility with myTarget SDK version 5.9.10.

Build and tested With:
- Google Mobile Ads SDK version 7.69.0.
- MyTarget SDK version 5.9.10

#### Version 5.9.9.1
- Fixed an issue where banner ads sometimes load with a larger size than requested.

Build and tested With:
- Google Mobile Ads SDK version 7.69.0.
- MyTarget SDK version 5.9.9

#### Version 5.9.9.0
- Verified compatibility with myTarget SDK version 5.9.9.

Build and tested With:
- Google Mobile Ads SDK version 7.69.0.
- MyTarget SDK version 5.9.9

#### Version 5.9.8.0
- Verified compatibility with myTarget SDK version 5.9.8.

Build and tested With:
- Google Mobile Ads SDK version 7.69.0.
- MyTarget SDK version 5.9.8

#### Version 5.9.7.0
- Verified compatibility with myTarget SDK version 5.9.7.
- Now requires Google Mobile Ads SDK version 7.69.0 or higher.

Build and tested With:
- Google Mobile Ads SDK version 7.69.0.
- MyTarget SDK version 5.9.7

#### Version 5.9.6.0
- Verified compatibility with myTarget SDK version 5.9.6.
- Added standardized adapter error codes and messages.

Build and tested With:
- Google Mobile Ads SDK version 7.68.0.
- MyTarget SDK version 5.9.6

#### Version 5.9.5.0
- Verified compatibility with myTarget SDK version 5.9.5.

Build and tested With:
- Google Mobile Ads SDK version 7.68.0.
- MyTarget SDK version 5.9.5

#### Version 5.9.4.0
- Verified compatibility with myTarget SDK version 5.9.4.

Build and tested With:
- Google Mobile Ads SDK version 7.68.0.
- MyTarget SDK version 5.9.4

#### Version 5.9.3.0
- Verified compatibility with myTarget SDK version 5.9.3.
- Now requires Google Mobile Ads SDK version 7.68.0 or higher.

Build and tested With:
- Google Mobile Ads SDK version 7.68.0.
- MyTarget SDK version 5.9.3

#### Version 5.9.2.0
- Added support for myTarget's adaptive banner ad size.
- Verified compatibility with myTarget SDK version 5.9.2.
- Now requires Google Mobile Ads SDK version 7.67.0 or higher.

Build and tested With:
- Google Mobile Ads SDK version 7.67.0.
- MyTarget SDK version 5.9.2

#### Version 5.7.5.0
- Verified compatibility with myTarget SDK version 5.7.5.

Build and tested With:
- Google Mobile Ads SDK version 7.64.0.
- MyTarget SDK version 5.7.5

#### Version 5.7.4.0
- Verified compatibility with myTarget SDK version 5.7.4.
- Now requires Google Mobile Ads SDK version 7.64.0 or higher.

Build and tested With:
- Google Mobile Ads SDK version 7.64.0.
- MyTarget SDK version 5.7.4

#### Version 5.7.3.0
- Verified compatibility with myTarget SDK version 5.7.3.
- Now requires Google Mobile Ads SDK version 7.63.0 or higher.

Build and tested With:
- Google Mobile Ads SDK version 7.63.0.
- MyTarget SDK version 5.7.3

#### Version 5.7.2.0
- Verified compatibility with myTarget SDK version 5.7.2.

Build and tested With:
- Google Mobile Ads SDK version 7.62.0.
- MyTarget SDK version 5.7.2

#### Version 5.7.1.0
- Verified compatibility with myTarget SDK version 5.7.1.

Build and tested With:
- Google Mobile Ads SDK version 7.61.0.
- MyTarget SDK version 5.7.1

#### Version 5.7.0.0
- Verified compatibility with myTarget SDK version 5.7.0.

Build and tested With:
- Google Mobile Ads SDK version 7.61.0.
- MyTarget SDK version 5.7.0

#### Version 5.6.3.0
- Verified compatibility with myTarget SDK version 5.6.3.
- Now requires Google Mobile Ads SDK version 7.61.0 or higher.

Build and tested With:
- Google Mobile Ads SDK version 7.61.0.
- MyTarget SDK version 5.6.3.

#### Version 5.6.2.0
- Verified compatibility with myTarget SDK version 5.6.2.

Build and tested With:
- Google Mobile Ads SDK version 7.60.0.
- MyTarget SDK version 5.6.2.

#### Version 5.6.1.0
- Verified compatibility with myTarget SDK version 5.6.1.

Build and tested With:
- Google Mobile Ads SDK version 7.60.0.
- MyTarget SDK version 5.6.1.

#### Version 5.6.0.0
- Verified compatibility with myTarget SDK version 5.6.0.
- Now requires Google Mobile Ads SDK version 7.60.0 or higher.

Build and tested With:
- Google Mobile Ads SDK version 7.60.0.
- MyTarget SDK version 5.6.0.

#### Version 5.5.2.0
- Verified compatibility with myTarget SDK version 5.5.2.
- Now requires Google Mobile Ads SDK version 7.59.0 or higher.

Build and tested With:
- Google Mobile Ads SDK version 7.59.0.
- MyTarget SDK version 5.5.2.

#### Version 5.5.1.0
- Verified compatibility with myTarget SDK version 5.5.1.
- Now requires Google Mobile Ads SDK version 7.58.0 or higher.

Build and tested With:
- Google Mobile Ads SDK version 7.58.0.
- MyTarget SDK version 5.5.1.

#### Version 5.4.9.0
- Verified compatibility with myTarget SDK version 5.4.9.
- Removed support for the i386 architecture.

Build and tested With:
- Google Mobile Ads SDK version 7.57.0.
- MyTarget SDK version 5.4.9.

#### Version 5.4.7.0
- Verified compatibility with myTarget SDK version 5.4.7.
- Now requires minimum iOS version 9.0.

Build and tested With:
- Google Mobile Ads SDK version 7.55.1.
- MyTarget SDK version 5.4.7.

#### Version 5.4.5.0
- Verified compatibility with myTarget SDK version 5.4.5.

Build and tested With:
- Google Mobile Ads SDK version 7.53.1.
- MyTarget SDK version 5.4.5.

#### Version 5.4.2.0
- Verified compatibility with myTarget SDK version 5.4.2.
- Adapter now returns a non-zero `mediaContent` aspect ratio.

Build and tested With:
- Google Mobile Ads SDK version 7.53.1.
- MyTarget SDK version 5.4.2.

#### Version 5.3.3.0
- Verified compatibility with myTarget SDK version 5.3.3.
- Removed support for Native Content and App Install ad requests. Apps must use the Unified Native Ads API to request native ads.
- Now requires Google Mobile Ads SDK version 7.46.0 or higher.

#### Version 5.0.4.0
- Verified compatibility with myTarget SDK version 5.0.4.
- Updated the adapter to use the new rewarded API.
- Now requires Google Mobile Ads SDK version 7.41.0 or higher.

#### Version 5.0.1.0
- Verified compatibility with myTarget SDK version 5.0.1.

#### Version 4.8.9.0
- Verified compatibility with myTarget SDK version 4.8.9.

#### Version 4.8.5.0
- Verified compatibility with myTarget SDK version 4.8.5.

#### Version 4.8.0.0
- Verified compatibility with myTarget SDK version 4.8.0.

#### Version 4.7.11.0
- Verified compatibility with myTarget SDK version 4.7.11.

#### Version 4.7.10.0
- Verified compatibility with myTarget SDK version 4.7.10.
- Added `adapterDidCompletePlayingRewardBasedVideoAd:` callback to the adapter.

#### Version 4.7.9.1
- Added support for Unified native ad.

#### Version 4.7.9.0
- Verified compatibility with myTarget SDK version 4.7.9.
- Added support for unified native ad.

#### Version 4.7.8.0
- Verified compatibility with myTarget SDK version 4.7.8.

#### Version 4.7.7.0
- Verified compatibility with myTarget SDK version 4.7.7.

#### Version 4.7.6.0
- Verified compatibility with myTarget SDK version 4.7.6.

#### Version 4.7.5.0
- Verified compatibility with myTarget SDK version 4.7.5.

#### Version 4.7.4.0
- Verified compatibility with myTarget SDK version 4.7.4.

#### Version 4.7.3.0
- Verified compatibility with myTarget SDK version 4.7.3.
- Added support for native video ads.

#### Version 4.6.25.0
- Verified compatibility with myTarget SDK version 4.6.25.

#### Version 4.6.24.0
- First release!
- Added support for banner, interstitial, rewarded, and native ads.
